@@ -24,49 +24,6 @@ spocc_capwords <- function(s, strict = FALSE, onlyfirst = FALSE) {
     }
 }
 
-#' Code based on the `gbifxmlToDataFrame` function from dismo package
-#' (http://cran.r-project.org/web/packages/dismo/index.html),
-#' by Robert Hijmans, 2012-05-31, License: GPL v3
-#' @import XML
-#' @param doc A parsed XML document.
-#' @param format Format to use.
-#' @export
-#' @keywords internal
-spocc_gbifxmlToDataFrame <- function(doc, format) {
-    nodes <- getNodeSet(doc, "//to:TaxonOccurrence")
-    if (length(nodes) == 0)
-        return(data.frame())
-    if (!is.null(format) & format == "darwin") {
-        varNames <- c("occurrenceID", "country", "stateProvince", "county", "locality",
-            "decimalLatitude", "decimalLongitude", "coordinateUncertaintyInMeters",
-            "maximumElevationInMeters", "minimumElevationInMeters", "maximumDepthInMeters",
-            "minimumDepthInMeters", "institutionCode", "collectionCode", "catalogNumber",
-            "basisOfRecordString", "collector", "earliestDateCollected", "latestDateCollected",
-            "gbifNotes")
-    } else {
-        varNames <- c("occurrenceID", "country", "decimalLatitude", "decimalLongitude",
-            "catalogNumber", "earliestDateCollected", "latestDateCollected")
-    }
-    dims <- c(length(nodes), length(varNames))
-    ans <- as.data.frame(replicate(dims[2], rep(as.character(NA), dims[1]), simplify = FALSE),
-        stringsAsFactors = FALSE)
-    names(ans) <- varNames
-    for (i in seq(length = dims[1])) {
-        ans[i, 1] <- xmlAttrs(nodes[[i]])[["gbifKey"]]
-        ans[i, -1] <- xmlSApply(nodes[[i]], xmlValue)[varNames[-1]]
-    }
-    nodes <- getNodeSet(doc, "//to:Identification")
-    varNames <- c("taxonName")
-    dims <- c(length(nodes), length(varNames))
-    tax <- as.data.frame(replicate(dims[2], rep(as.character(NA), dims[1]), simplify = FALSE),
-        stringsAsFactors = FALSE)
-    names(tax) <- varNames
-    for (i in seq(length = dims[1])) {
-        tax[i, ] <- xmlSApply(nodes[[i]], xmlValue)[varNames]
-    }
-    cbind(tax, ans)
-}
-
 #' Coerces data.frame columns to the specified classes
 #'
 #' @param d A data.frame.
@@ -101,26 +58,24 @@ spocc_blanktheme <- function() {
 }
 
 #' Combine results from occ calls to a single data.frame
-#' @importFrom plyr rbind.fill
 #' @param obj Input from occ
 #' @param what One of data (default) or all (with metadata)
 #' @export
 #' @examples \dontrun{
-#' spnames <- c('Accipiter striatus', 'Setophaga caerulescens', 'Spinus tristis')
-#' out <- occ(query=spnames, from='gbif', gbifopts=list(hasCoordinate=TRUE))
+#' spnames <- c('Accipiter striatus', 'Setophaga caerulescens', 'Carduelis tristis')
+#' out <- occ(query=spnames, from='gbif', gbifopts=list(hasCoordinate=TRUE), limit=10)
 #' occ2df(out)
 #' }
 occ2df <- function(obj, what = "data") {
     what <- match.arg(what, choices = c("all", "data"))
-#     foolist <- function(x) data.frame(rbindlist(x$data), stringsAsFactors = FALSE)
-    foolist <- function(x) do.call(rbind.fill, x$data)
+    foolist <- function(x) do.call(rbind_fill, x$data)
     aa <- foolist(obj$gbif)
     bb <- foolist(obj$bison)
     cc <- foolist(obj$inat)
     dd <- foolist(obj$ebird)
     ee <- foolist(obj$ecoengine)
     aw <- foolist(obj$antweb)
-    tmp <- data.frame(rbindlist(
+    tmp <- data.frame(rbind_fill(
       lapply(list(aa, bb, cc, dd, ee, aw), function(x){
         if(NROW(x) == 0) data.frame(NULL) else x[ , c('name','longitude','latitude','prov') ]
       })
@@ -136,40 +91,6 @@ occ2df <- function(obj, what = "data") {
 #       data.frame(name = aw$name, longitude = aw$decimal_longitude, latitude = aw$decimal_latitude, prov = aw$prov))))
 }
 
-#' Occ output or data.frame to sp SpatialPointsDataFrame class
-#'
-#' @import sp assertthat
-#' @param input Output from \code{\link{occ}} or a data.frame
-#' @details Note that you must have a column named latitude and a column named
-#' longitude - any additional columns are fine, but those two columns must exist.
-#' If you are using \code{\link{occ}} this will be done for you as you pass in the
-#' output of occ as an occdat class, but if you pass in a data.frame you should check
-#' this.
-#' @export
-#' @examples \dontrun{
-#' spnames <- c('Accipiter striatus', 'Setophaga caerulescens', 'Spinus tristis')
-#' out <- occ(query=spnames, from='gbif', limit=25, gbifopts=list(hasCoordinate=TRUE))
-#'
-#' # pass in output of occ directly to occ2sp
-#' occ2sp(out)
-#'
-#' # or make a data.frame first, then pass in
-#' mydf <- occ2df(out)
-#' occ2sp(mydf)
-#' }
-occ2sp <- function(input) {
-    # check class
-    assert_that(is(input, "occdat") | is(input, "data.frame"))
-    dat <- switch(class(input), occdat = occ2df(input), data.frame = input)
-    # check column names
-    assert_that(all(c("latitude", "longitude") %in% names(dat)))
-    # remove NA rows
-    dat <- dat[complete.cases(dat),]
-    # convert to SpatialPointsDataFrame object
-    coordinates(dat) <- c("latitude", "longitude")
-    return(dat)
-}
-
 #' Convert a bounding box to a Well Known Text polygon, and a WKT to a bounding box
 #'
 #' @import rgeos
@@ -204,9 +125,9 @@ occ2sp <- function(input) {
 bbox2wkt <- function(minx=NA, miny=NA, maxx=NA, maxy=NA, bbox=NULL){
   if(is.null(bbox)) bbox <- c(minx, miny, maxx, maxy)
 
-  assert_that(length(bbox)==4) #check for 4 digits
-  assert_that(noNA(bbox)) #check for NAs
-  assert_that(is.numeric(as.numeric(bbox))) #check for numeric-ness
+  stopifnot(length(bbox)==4) #check for 4 digits
+  stopifnot(!any(is.na(bbox))) #check for NAs
+  stopifnot(is.numeric(as.numeric(bbox))) #check for numeric-ness
   paste('POLYGON((',
         sprintf('%s %s',bbox[1],bbox[2]), ',', sprintf(' %s %s',bbox[3],bbox[2]), ',',
         sprintf(' %s %s',bbox[3],bbox[4]), ',', sprintf(' %s %s',bbox[1],bbox[4]), ',',
@@ -219,7 +140,7 @@ bbox2wkt <- function(minx=NA, miny=NA, maxx=NA, maxy=NA, bbox=NULL){
 #' @rdname bbox2wkt
 
 wkt2bbox <- function(wkt=NULL){
-  assert_that(!is.null(wkt))
+  stopifnot(!is.null(wkt))
   tmp <- bbox(readWKT(wkt))
   as.vector(tmp)
 }
@@ -346,40 +267,40 @@ spocc_obj_type <- function (x)
 }
 
 
-spocc_compact <- function (l) Filter(Negate(is.null), l)
+sc <- function (l) Filter(Negate(is.null), l)
 
 spocc_inat_obs <- function(query=NULL,taxon = NULL,quality=NULL,geo=NULL,year=NULL,month=NULL,day=NULL,bounds=NULL,maxresults=100,meta=FALSE)
-{  
-  
+{
+
   ## Parsing and error-handling of input strings
   search <- ""
   if(!is.null(query)){
     search <- paste(search,"&q=",gsub(" ","+",query),sep="")
   }
-  
+
   if(!is.null(quality)){
     if(!sum(grepl(quality,c("casual","research")))){
       stop("Please enter a valid quality flag,'casual' or 'research'.")
     }
-    
+
     search <- paste(search,"&quality_grade=",quality,sep="")
   }
-  
+
   if(!is.null(taxon)){
     search <-  paste(search,"&taxon_name=",gsub(" ","+",taxon),sep="")
   }
-  
+
   if(!is.null(geo) && geo){
     search <- paste(search,"&has[]=geo",sep="")
   }
-  
+
   if(!is.null(year)){
     if(length(year) > 1){
       stop("you can only filter results by one year, please enter only one value for year")
     }
     search <- paste(search,"&year=",year,sep="")
   }
-  
+
   if(!is.null(month)){
     month <- as.numeric(month)
     if(is.na(month)){
@@ -391,7 +312,7 @@ spocc_inat_obs <- function(query=NULL,taxon = NULL,quality=NULL,geo=NULL,year=NU
     if(month < 1 || month > 12){ stop("Please enter a valid month between 1 and 12")}
     search <- paste(search,"&month=",month,sep="")
   }
-  
+
   if(!is.null(day)){
     day <- as.numeric(day)
     if(is.na(day)){
@@ -401,16 +322,16 @@ spocc_inat_obs <- function(query=NULL,taxon = NULL,quality=NULL,geo=NULL,year=NU
       stop("you can only filter results by one day, please enter only one value for day")
     }
     if(day < 1 || day > 31){ stop("Please enter a valid day between 1 and 31")}
-    
+
     search <- paste(search,"&day=",day,sep="")
   }
-  
+
   if(!is.null(bounds)){
     if(length(bounds) != 4){stop("bounding box specifications must have 4 coordinates")}
     search <- paste(search,"&swlat=",bounds[1],"&swlng=",bounds[2],"&nelat=",bounds[3],"&nelng=",bounds[4],sep="")
-    
+
   }
-  
+
   base_url <- "http://www.inaturalist.org/"
   q_path <- "observations.csv"
   ping_path <- "observations.json"
@@ -420,16 +341,16 @@ spocc_inat_obs <- function(query=NULL,taxon = NULL,quality=NULL,geo=NULL,year=NU
   ### that come down in CSV format
   ping <-  GET(base_url, path = ping_path, query = ping_query)
   total_res <- as.numeric(ping$headers$`x-total-entries`)
-  
+
   if(total_res == 0){
     stop("Your search returned zero results.  Either your species of interest has no records or you entered an invalid search")
   }
-  
+
   page_query <- paste(search,"&per_page=200&page=1",sep="")
   data <-  GET(base_url, path = q_path, query = page_query)
   data <- spocc_inat_handle(data)
   data_out <- if(is.na(data)) NA else read.csv(textConnection(data), stringsAsFactors = FALSE)
-  
+
   if(total_res < maxresults) maxresults <- total_res
   if(maxresults > 200){
     for(i in 2:ceiling(maxresults/200)){
@@ -439,15 +360,15 @@ spocc_inat_obs <- function(query=NULL,taxon = NULL,quality=NULL,geo=NULL,year=NU
       data_out <- rbind(data_out, read.csv(textConnection(data), stringsAsFactors = FALSE))
     }
   }
-  
+
   if(is.data.frame(data_out)){
     if(maxresults < dim(data_out)[1]){
       data_out <- data_out[1:maxresults,]
     }
   }
-  
-  if(meta){ 
-    return(list(meta=list(found=total_res, returned=nrow(data_out)), data=data_out)) 
+
+  if(meta){
+    return(list(meta=list(found=total_res, returned=nrow(data_out)), data=data_out))
   } else { return(data_out) }
 }
 
